Struct sp_runtime::testing::sr25519::Signature
pub struct Signature(pub [u8; 64]);Expand description
An Schnorrkel/Ristretto x25519 (“sr25519”) signature.
Tuple Fields
0: [u8; 64]Implementations
impl Signature
impl Signature
pub fn from_raw(data: [u8; 64]) -> Signature
pub fn from_raw(data: [u8; 64]) -> Signature
A new instance from the given 64-byte data.
NOTE: No checking goes on to ensure this is a real signature. Only use
it if you are certain that the array actually is a signature, or if you
immediately verify the signature. All functions that verify signatures
will fail if the Signature is not actually a valid signature.
pub fn from_slice(data: &[u8]) -> Option<Signature>
pub fn from_slice(data: &[u8]) -> Option<Signature>
A new instance from the given slice that should be 64 bytes long.
NOTE: No checking goes on to ensure this is a real signature. Only use it if you are certain that the array actually is a signature. GIGO!